@@ -1,7 +1,8 @@
 from enum import Enum
 
 from .load_shedding import (
-    Area, Stage, StageError, ProviderError, get_areas, get_schedule, get_stage, get_stage_forecast
+    Area, Stage, StageError, ProviderError,
+    get_areas, get_area_schedule, get_stage, get_stage_forecast, get_area_forecast
 )
 from .providers import Province, coct, eskom
 
