@@ -114,7 +114,7 @@ TIMESLOTS: List[List] = [
 ]
 
 
-def get_schedule(area, stage, days=30):
+def get_schedule(area: Area, stage: Stage, days=30):
     """ Returns a schedule for the given area, stage and number of days."""
     schedule: List[Tuple] = []
     sast = timezone(timedelta(hours=+2), 'SAST')
@@ -122,7 +122,7 @@ def get_schedule(area, stage, days=30):
     day = today
 
     while day < today + timedelta(days=days):
-        timeslots = get_time_slots_by_area_code(stage.value, day.day, area.id)
+        timeslots = get_time_slots_by_area_code(stage.value, day.day, area.value)
 
         for ts in timeslots:
             start = ts[0].replace(year=day.year, month=day.month, day=day.day, tzinfo=sast)
