@@ -13,9 +13,10 @@
 #
 #      You should have received a copy of the GNU General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
+from datetime import timezone
 from typing import List, Tuple
 
-from load_shedding.libs import eskom
+from load_shedding.libs import eskom, citypower
 from load_shedding.providers import dict_list_to_obj_list, ProviderError, to_utc
 from load_shedding.providers import Area, Province, Stage, Provider
 
@@ -44,14 +45,14 @@ class Eskom(Provider):
             areas = dict_list_to_obj_list(areas, Area)
             return filter_empty_areas(areas)
 
-    def get_schedule(self, area: Area, stage: Stage) -> List[Tuple]:
+    def get_area_schedule(self, area: Area, stage: Stage) -> List[Tuple]:
         try:
-            schedule = self.api.get_schedule(province=area.province.value, suburb_id=area.id, stage=stage.value)
+            area_schedule = self.api.get_schedule(province=area.province.value, suburb_id=area.id, stage=stage.value)
         except Exception as e:
             raise ProviderError(e)
         else:
-            schedule = to_utc(schedule)
-            return schedule
+            area_schedule = to_utc(area_schedule)
+            return area_schedule
 
     def get_stage(self) -> Stage:
         try:
@@ -61,6 +62,20 @@ class Eskom(Provider):
         else:
             return stage_from_status(status)
 
+    def get_stage_forecast(self) -> List:
+        """ Get Stage forecast from City Power."""
+        try:
+            stage_forecast = citypower.get_stage_forecast()
+
+            for i in range(len(stage_forecast)):
+                stage_forecast[i]["stage"] = Stage(stage_forecast[i].get("stage"))
+                stage_forecast[i]["start_time"] = stage_forecast[i]["start_time"].astimezone(timezone.utc)
+                stage_forecast[i]["end_time"] = stage_forecast[i]["end_time"].astimezone(timezone.utc)
+        except Exception as e:
+            raise ProviderError(e)
+        else:
+            return stage_forecast
+
 
 def stage_from_status(status: int) -> Stage:
     return {
